@@ -13,15 +13,14 @@ import typing_extensions
 
 from typeguard import check_type
 
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-lambda-layer-curl",
-    "1.0.862",
+    "2.0.816",
     __name__[0:-6],
-    "cdk-lambda-layer-curl@1.0.862.jsii.tgz",
+    "cdk-lambda-layer-curl@2.0.816.jsii.tgz",
 )
 
 __all__ = [
